#include "mainwindow.h"
#include "ui_mainwindow.h"

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);
    ui->treeWidget->setColumnCount(3);
    on_pushButton_clicked();
}

MainWindow::~MainWindow()
{
    delete ui;
}

#include <QDir>
#include <QDateTime>

void MainWindow::showDir (QTreeWidgetItem * target,
                          QDir dir,
                          int level)
{
    QFileInfoList list = dir.entryInfoList
            (QDir::NoDotAndDotDot | QDir::AllEntries, QDir::Name);

    for (QFileInfo info : list)
    {
        QTreeWidgetItem * node = new QTreeWidgetItem;
        node->setText (0, info.fileName());

        QString path = info.absoluteFilePath();
        node->setToolTip(0, path);
        node->setData (0, Qt::UserRole, path);

        node->setText(1, QString::number(info.size()));

        // #include <QDateTime>
        QString s = info.lastModified().toString ("dd-MM-yyyy hh:mm");
        node->setText(2, s);

        QColor color;
        if (info.isDir())
            color = QColor ("red");
        else
            color= QColor ("blue");
        node->setForeground (0, color);

        QIcon icon ;
        if (info.isDir())
           icon = QIcon::fromTheme ("folder");
        else
           if (info.suffix() == "png")
              icon = QIcon (path);
        node->setIcon (0, icon);

        target->addChild (node);

        if (info.isDir() && level > 1)
           showDir (node, QDir (path), level-1);
    }
}

void MainWindow::on_pushButton_clicked()
{
    // QDir dir ("/usr/share/icons/oxygen/base/64x64");
    QDir dir (".");

    QTreeWidgetItem * item = new QTreeWidgetItem;
    QString path = dir.absolutePath();
    item->setText (0, path);
    item->setToolTip(0, path);
    item->setData (0, Qt::UserRole, path);
    item->setForeground (0, QColor ("red"));
    // ui->treeWidget->addTopLevelItem (item);
    ui->treeWidget->invisibleRootItem()->addChild(item);

    showDir (item, dir, 5);
    ui->treeWidget->expandAll();
}

void MainWindow::on_treeWidget_itemClicked
     (QTreeWidgetItem *item, int column)
{
    QString path = item->data (0, Qt::UserRole).toString();

    QFileInfo fi (path);
    QString ext = fi.suffix();

    if (ext == "cpp")
        readText (path);
}

void MainWindow::readText (QString path)
{
    QFile f (path);

    if (f.open (QIODevice::ReadOnly | QIODevice::Text))
    {
        QByteArray b = f.readAll();
        ui->textEdit->setText (b);
    }
}


void MainWindow::on_action_Quit_triggered()
{
    close ();
}

